@@ -34,6 +34,8 @@ class Command(BaseCommand):
     usage_str = "Usage: ./manage.py datamigration appname migrationname [--stdout] [--freeze appname]"
     
     def handle(self, app=None, name="", freeze_list=None, stdout=False, verbosity=1, **options):
+
+        verbosity = int(verbosity)
         
         # Any supposed lists that are None become empty lists
         freeze_list = freeze_list or []
@@ -46,13 +48,19 @@ class Command(BaseCommand):
         if re.search('[^_\w]', name) and name != "-":
             self.error("Migration names should contain only alphanumeric characters and underscores.")
         
-        # if not name, there's an error
+        # If not name, there's an error
         if not name:
-            self.error("You must provide a name for this migration\n" + self.usage_str)
+            self.error("You must provide a name for this migration.\n" + self.usage_str)
         
         if not app:
             self.error("You must provide an app to create a migration for.\n" + self.usage_str)
-        
+
+        # Ensure that verbosity is not a string (Python 3)
+        try:
+            verbosity = int(verbosity)
+        except ValueError:
+            self.error("Verbosity must be an number.\n" + self.usage_str)
+            
         # Get the Migrations for this app (creating the migrations dir if needed)
         migrations = Migrations(app, force_creation=True, verbose_creation=verbosity > 0)
         
@@ -63,7 +71,7 @@ class Command(BaseCommand):
         apps_to_freeze = self.calc_frozen_apps(migrations, freeze_list)
         
         # So, what's in this file, then?
-        file_contents = MIGRATION_TEMPLATE % {
+        file_contents = self.get_migration_template() % {
             "frozen_models":  freezer.freeze_apps_to_string(apps_to_freeze),
             "complete_apps": apps_to_freeze and "complete_apps = [%s]" % (", ".join(map(repr, apps_to_freeze))) or ""
         }
@@ -103,6 +111,9 @@ class Command(BaseCommand):
         print(message, file=sys.stderr)
         sys.exit(code)
 
+    def get_migration_template(self):
+        return MIGRATION_TEMPLATE
+
 
 MIGRATION_TEMPLATE = """# -*- coding: utf-8 -*-
 import datetime
